@@ -1,5 +1,6 @@
 import os
 import re
+from typing import Any, Optional
 
 
 def validate_uuid(value: str, error_message='Invalid uuid format'):
@@ -11,6 +12,11 @@ def validate_path(value: str, error_message='Path does not exist'):
         raise ValueError(error_message)
 
 
+def validate_not_empty(value: Optional[Any], error_message='Value is None or empty'):
+    if not value:
+        raise ValueError(error_message)
+
+
 def _validate_regex(value: str,
                     regex: str,
                     error_message: str):
